@@ -18,7 +18,7 @@ class DaylessDateSelect(MultiWidget):
         super().__init__(widgets=widgets, *args, **kwargs)
 
     def decompress(self, value):
-        if value is None:
+        if not value:
             return [None, None]
         return [value.month, value.year]
 
@@ -27,8 +27,10 @@ class DaylessDateField(forms.Field):
     widget = DaylessDateSelect
 
     def clean(self, value):
+        if all([x in self.empty_values for x in value]):
+            return self.empty_value
         try:
-            value = DaylessDate(*value) if value != ['', ''] else None
+            value = DaylessDate(*value)
         except:
             raise ValidationError('Invalid date.')
         return value
\ No newline at end of file
