@@ -1,4 +1,4 @@
-from django.db import models
+from django.db import models, connection
 from .helpers import DaylessDate
 from . import forms
 
@@ -19,19 +19,23 @@ class DaylessDateField(models.Field):
         return self.to_python(value)
 
     def get_prep_value(self, value):
-        if value is not None and isinstance(value, DaylessDate):
+        if value and isinstance(value, DaylessDate):
             return ''.join(['{:02d}'.format(x) for x in (value.year, value.month)])
 
     def get_internal_type(self):
         return 'CharField'
 
     def to_python(self, value):
-        if isinstance(value, DaylessDate) or value is None:
+        if isinstance(value, DaylessDate) or not value:
             return value
         return DaylessDate(value[-2:], value[:4])
 
     def formfield(self, **kwargs):
+        defaults = {}
+        if self.null and not connection.features.interprets_empty_strings_as_nulls:
+            defaults['empty_value'] = None
+        defaults.update(kwargs)
         return super().formfield(**{
             'form_class': forms.DaylessDateField,
-            **kwargs,
+            **defaults
         })
\ No newline at end of file
